%define anolis_release 4
%global libname      lib%{name}
%global soname       1


Name:    argon2
Version: 20190702
Release: %{anolis_release}%{?dist}
Summary: The password-hashing tools
License: Public Domain or ASL 2.0
URL:     https://github.com/P-H-C/phc-winner-argon2
Source0: https://github.com/P-H-C/phc-winner-argon2/archive/refs/tags/%{version}.tar.gz

BuildRequires: gcc > 12.0, make
Requires: lib%{name} = %{version}-%{release}


%description
Argon2 is a password-hashing function that summarizes the state of the art
in the design of memory-hard functions and can be used to hash passwords
for credential storage, key derivation, or other applications.

It has a simple design aimed at the highest memory filling rate and
effective use of multiple computing units, while still providing defense
against tradeoff attacks (by exploiting the cache and memory organization
of the recent processors).

Argon2 has three variants: Argon2i, Argon2d, and Argon2id.

* Argon2d is faster and uses data-depending memory access, which makes it
  highly resistant against GPU cracking attacks and suitable for applications
  with no threats from side-channel timing attacks (eg. cryptocurrencies).
* Argon2i instead uses data-independent memory access, which is preferred for
  password hashing and password-based key derivation, but it is slower as it
  makes more passes over the memory to protect from tradeoff attacks.
* Argon2id is a hybrid of Argon2i and Argon2d, using a combination of
  data-depending and data-independent memory accesses, which gives some of
  Argon2i's resistance to side-channel cache timing attacks and much of
  Argon2d's resistance to GPU cracking attacks.

Argon2i, Argon2d, and Argon2id are parametrized by:

* A time cost, which defines the amount of computation realized and therefore
  the execution time, given in number of iterations
* A memory cost, which defines the memory usage, given in kibibytes
* A parallelism degree, which defines the number of parallel threads


%package -n lib%{name}
Summary:  The password-hashing library

%description -n lib%{name}
Argon2 is a password-hashing function that summarizes the state of the art
in the design of memory-hard functions and can be used to hash passwords
for credential storage, key derivation, or other applications.

It has a simple design aimed at the highest memory filling rate and
effective use of multiple computing units, while still providing defense
against tradeoff attacks (by exploiting the cache and memory organization
of the recent processors).


%package -n lib%{name}-devel
Summary:  Development files for lib%{name}
Requires: lib%{name} = %{version}-%{release}

%description -n lib%{name}-devel
The lib%{name}-devel package contains libraries and header files for
developing applications that use lib%{name}.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.


%prep
%setup -qn phc-winner-argon2-%{version}

if ! grep -q 'ABI_VERSION = %{soname}' Makefile; then
  : soname have changed
  grep soname Makefile
  exit 1
fi

sed -e 's:lib/@HOST_MULTIARCH@:%{_lib}:;s/@UPSTREAM_VER@/%{version}/' -i lib%{name}.pc.in

%build
sed -e '/^CFLAGS/s:^CFLAGS:LDFLAGS=%{build_ldflags}\nCFLAGS:' \
    -e 's:-O3 -Wall:%{optflags}:' \
    -e '/^LIBRARY_REL/s:lib:%{_lib}:' \
    -e 's:-march=\$(OPTTARGET) :${CFLAGS} :' \
    -e 's:CFLAGS += -march=\$(OPTTARGET)::' \
    -i Makefile

sed -e 's/\/x86_64-linux-gnu//g' -i Makefile

make -j1


%install
make install DESTDIR=%{buildroot}

rm %{buildroot}%{_libdir}/lib%{name}.a

install -Dpm 0644 lib%{name}.pc %{buildroot}%{_libdir}/pkgconfig/lib%{name}.pc

chmod -x %{buildroot}%{_includedir}/%{name}.h

%generate_compatibility_deps

%check
make test


%files
%{_bindir}/%{name}

%files -n lib%{name}
%dir %{abidir}
%license LICENSE
%{_libdir}/lib%{name}.so*
%{abidir}/libargon2.dump

%files -n lib%{name}-devel
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/*pc

%files doc
%doc CHANGELOG.md README.md

%changelog
* Tue Dec 19 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 20190702-4
- rebuild

* Tue Apr 11 2023 Ziyang Zhang <ZiyangZhang@linux.alibaba.com> - 20190702-3
- Optimize spec file

* Fri Feb 10 2023 happy_orange <songnannan@linux.alibaba.com> - 20190702-2
- add generate compatibility scripts and doc package

* Wed Apr 13 2022 yuanhui <yuanhui@linux.alibaba.com> - 20190702-1
- Init argon2 for anolis os 23
